@@ -26,7 +26,6 @@
 #include <QJsonDocument>
 #include <QJsonArray>
 #include <QCoreApplication>
-#include <QPointer>
 #include "kpackage_debug.h"
 
 #include <KCompressionDevice>
@@ -172,9 +171,13 @@ QList<KPluginMetaData> PackageLoader::listPackages(const QString &packageFormat,
         useRuntimeCache = false;
         d->pluginCache.clear();
     }
-    QString cacheKey = QString(QStringLiteral("%1.%2")).arg(packageFormat, packageRoot);
-    if (useRuntimeCache && d->pluginCache.contains(cacheKey)) {
-        return d->pluginCache.value(cacheKey);
+
+    const QString cacheKey = QStringLiteral("%1.%2").arg(packageFormat, packageRoot);
+    if (useRuntimeCache) {
+        auto it = d->pluginCache.constFind(cacheKey);
+        if (it != d->pluginCache.constEnd()) {
+            return *it;
+        }
     }
     if (d->pluginCacheAge == 0) {
         d->pluginCacheAge = now;
@@ -225,8 +228,8 @@ QList<KPluginMetaData> PackageLoader::listPackages(const QString &packageFormat,
 
     for (auto const &plugindir : qAsConst(paths)) {
         const QString &_ixfile = plugindir + s_kpluginindex;
-        KCompressionDevice indexFile(_ixfile, KCompressionDevice::BZip2);
         if (QFile::exists(_ixfile)) {
+            KCompressionDevice indexFile(_ixfile, KCompressionDevice::BZip2);
             qCDebug(KPACKAGE_LOG) << "kpluginindex: Using indexfile: " << _ixfile;
             indexFile.open(QIODevice::ReadOnly);
             QJsonDocument jdoc = QJsonDocument::fromBinaryData(indexFile.readAll());
